@@ -6,10 +6,13 @@
 # :Copyright: © 2016, 2017 Lele Gaifax
 #
 
+import io
 import json
 
 import pytest
 
+import rapidjson
+
 
 @pytest.mark.unit
 @pytest.mark.parametrize('u', [
